Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(69)

Unified Diff: editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/IParameterListChangeListener_NEW.java

Issue 554143003: Integrate the EXTRACT_METHOD refactoring into Editor. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/IParameterListChangeListener_NEW.java
diff --git a/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/IParameterListChangeListener.java b/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/IParameterListChangeListener_NEW.java
similarity index 74%
copy from editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/IParameterListChangeListener.java
copy to editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/IParameterListChangeListener_NEW.java
index 32d8a55cc3a3fc9e9e3e86ef237f4d98e9485f2a..35eed9a5e6239e1ce46c30c70e2164fd921eca5a 100644
--- a/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/IParameterListChangeListener.java
+++ b/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/IParameterListChangeListener_NEW.java
@@ -13,23 +13,23 @@
*/
package com.google.dart.tools.ui.internal.refactoring;
-import com.google.dart.engine.services.refactoring.Parameter;
+import com.google.dart.server.generated.types.RefactoringMethodParameter;
/**
* @coverage dart.editor.ui.refactoring.ui
*/
-public interface IParameterListChangeListener {
+public interface IParameterListChangeListener_NEW {
/**
* Empty implementation of {@link IParameterListChangeListener}.
*/
- class Empty implements IParameterListChangeListener {
+ class Empty implements IParameterListChangeListener_NEW {
@Override
- public void parameterAdded(Parameter parameter) {
+ public void parameterAdded(RefactoringMethodParameter parameter) {
}
@Override
- public void parameterChanged(Parameter parameter) {
+ public void parameterChanged(RefactoringMethodParameter parameter) {
}
@Override
@@ -42,14 +42,14 @@ public interface IParameterListChangeListener {
*
* @param parameter the parameter that has been added.
*/
- void parameterAdded(Parameter parameter);
+ void parameterAdded(RefactoringMethodParameter parameter);
/**
* Gets fired when the given parameter has changed
*
* @param parameter the parameter that has changed.
*/
- void parameterChanged(Parameter parameter);
+ void parameterChanged(RefactoringMethodParameter parameter);
/**
* Gets fired if the parameter list got modified by reordering or removing parameters (note that
@@ -13,23 +13,23 @@
/**
- * Empty implementation of {@link IParameterListChangeListener}.
+ * Empty implementation of {@link IParameterListChangeListener_NEW}.
*/

Powered by Google App Engine
This is Rietveld 408576698